<?php
/****************************************************************************************
Software released under the General Public License (version 2 or later), available at
http://www.gnu.org/copyleft/gpl.html

Mesures pour faire l'arrondi du plancher

@history 2007.03.13 : Creation
@author Thierry Graff - tig12.net
****************************************************************************************/

// *** Variables a modifier pour adapter a sa situation ***
// Choix du format d'affichage
// 3 valeurs possibles :
// - 'hor' : Affiche les valeurs dans 2 lignes
// - 'ver' : Affiche les valeurs dans 2 colonnes
// - 'img' : Affiche l'image d'un plan
$format = 'hor';
// Variables de la yourte
$R = 330; // rayon de la yourte, en cm
$n = 8; // nb de divisions du cercle
// Variables  choisir ici
$delta = 10; // cart entre 2 mesures, en cm

// *** Variables importantes ***
$alpha = M_PI / $n;
$ndiv = ceil($R * sin($alpha) / $delta);
$AB = 2 * $R * sin($alpha);

// Affichage du rsultat
$res = '';
if($format == 'hor' || $format == 'ver'){
  $res .= "<b>R = $R cm</b> : rayon yourte\n";
  $res .= "<br/><b>n = $n</b> : nb de divisions du cercle\n";
  $res .= "<br/><b>&delta; = $delta cm</b>\n";
  $res .= "<br/>\n";
  $res .= "<br/><b>AB = " . round($AB, 1) . " cm</b>\n";
  $res .= "<br/><b>AB / 2 = " . round($AB/2, 1) . " cm</b>\n";
  $res .= "<br/><br/>\n";
  $res .= "\n";
}

switch($format){
  case 'hor' : // affichage horizontal
    for($i=0; $i < $ndiv; $i++){
      $x[$i] = $delta * $i;
      $alphai = asin($x[$i] / $R);
      $y[$i] = $R * (cos($alphai) - cos($alpha));
    }
    //
    $res.= "<table style='border-collapse:collapse'>\n";
    $res.= "<tr>\n";
    $res.= "<th>x&nbsp;&nbsp;</th>\n";
    for($i=0; $i < $ndiv; $i++){
      $res .= "<td valign='top' style='padding:4px; border:1px solid black'>";
      $res .= round($x[$i], 1);
      $res .= "</td>\n";
    }
    $res.= "</tr>\n";
    //
    $res.= "<tr>\n";
    $res.= "<th>y&nbsp;&nbsp;</th>\n";
    for($i=0; $i < $ndiv; $i++){
      $res .= "<td valign='top' style='padding:4px; border:1px solid black'>";
      $res .= round($y[$i], 1);
      $res .= "</td>\n";
    }
    $res.= "</tr>\n";
    $res.= "</table>\n";
  break;
  
  case 'ver' : // affichage vertical
    $res.= "<table style='border-collapse:collapse'>\n";
    $res.= "<th>x</th><th>y</th>\n";
    for($i=0; $i < $ndiv; $i++){
      $x = $delta * $i;
      $alphai = asin($x / $R);
      $y = $R * (cos($alphai) - cos($alpha));
      $res.= "<tr>\n";
      $res .= "<td valign='top' style='padding:4px; border:1px solid black'>";
      $res .= round($x, 1);
      $res .= "</td>\n";
      $res .= "<td valign='top' style='padding:4px; border:1px solid black'>";
      $res .= round($y, 1);
      $res .= "</td>\n";
      $res.= "</tr>\n";
    }
    $res.= "</table>\n";
  break;
  
  case 'img' : // affiche une image
    $ymax = $R * (1 - cos($alpha)); // valeur max pour y
    // parametres de l'image
    $font = 'C:/WINDOWS/Fonts/ARIAL.TTF';
    $hgap = 10; $vgap = 10; // espace inutile laiss au bord de l'image
    $gap = 4; // espace entre les chiffres et le dessin
    $fs = 12; // font size
    $scaleV = 5; // facteur d'echelle vertical; 1 cm <--> $scaleV px
    $scaleH = 4 * $fs; // facteur d'echelle horizontal ; definition un peu batarde
    $pointSize = 4;
    // Dimensions de l'image
    $w = $ndiv * $scaleH + 2*$hgap;
    $h = $ymax * $scaleV + 2*$fs + 2*$gap + 2*$vgap;
    // Creation de l'image
    $img = imagecreate($w, $h);
    $white = imagecolorallocate($img, 255, 255, 255);
    $black = imagecolorallocate($img, 0, 0, 0);
    // Pour les lignes pointille
    $style = array($black, $black, $black, $black, $black, $white, $white, $white, $white, $white);
    imagesetstyle($img, $style);
    // Remplissage de l'image
    for($i=0; $i < $ndiv; $i++){
      $x = $delta * $i;
      $alphai = asin($x / $R);
      $y = $R * (cos($alphai) - cos($alpha));
      $xImg = $i*$scaleH + $hgap;
      $yImg1 = $h - $vgap - $fs;
      imagefilledellipse($img, $xImg, $yImg1-$gap, $pointSize, $pointSize, $black);
      imagettftext($img, $fs, 0, $xImg - $fs*2/3, $yImg1 + $fs, $black, $font, $x);
      $yImg2 = $vgap + $fs + $gap + ($ymax - $y) * $scaleV;
      imagefilledellipse($img, $xImg, $yImg2-$gap, $pointSize, $pointSize, $black);
      imagettftext($img, $fs, 0, $xImg - $fs*2/3, $yImg2 - $fs, $black, $font, round($y, 1));
      imageLine($img, $xImg, $yImg1, $xImg, $yImg2, IMG_COLOR_STYLED);
    }
    imageLine($img, $hgap, $yImg1-$gap, $xImg, $yImg1-$gap, $black);
    header("Content-type: image/png");
    imagepng($img);
    exit;
  break;
}

if($format == 'hor' || $format == 'ver'){
  echo $res;
}
exit;

// Auxiliary functions
function format($nb){
  return round($nb, 1);
  if($nb < 100)
    return round($nb, 1);
  $m = floor($nb / 100);
  $cm = $nb - 100*$m;
  return $m . ' m ' . round($cm, 1) * 10;
}

?>